/*
 * Copyright (c) 1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *
 * 4. The names "Java Apache Element Construction Set", "Java Apache ECS" and 
 *    "Java Apache Project" must not be used to endorse or promote products 
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called 
 *    "Java Apache Element Construction Set" nor "Java Apache ECS" appear 
 *    in their names without prior written permission of the 
 *    Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *    
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Project. For more information
 * on the Java Apache Project please see <http://java.apache.org/>.
 *
 */
package org.apache.ecs;

/**
    This class creates a &lt;TABLE&gt; object.
    @version $Id: Table.java,v 1.8 1999/06/08 21:29:14 stephan Exp $
    @author <a href="mailto:snagy@servletapi.com">Stephan Nagy</a>
    @author <a href="mailto:jon@clearink.com">Jon S. Stevens</a>
*/
public class Table extends MultiPartElement
{
    /**
        Private iniitialization routine
    */
    {
        setElementType("table");
    }
    public Table()
    {
    }

    /**
        Set the SUMMARY="" attribue.

        @param summary  sets the SUMMARY="" attribute.
    */
    public Table setSummary(String summary)
    {
        addAttribute("summary",summary);
        return(this);
    }

    /**
        Sets the ALIGN="" attribute.

        @param  align sets the ALIGN="" attribute. You can
        use the AlignType.* variables for convience.
    */
    public Table setAlign(String align)
    {
        addAttribute("align",align);
        return(this);
    }

    /**
        Sets the WIDTH="" attribute.

        @param  width sets the WIDTH="" attribute.
    */
    public Table setWidth(String width)
    {
        addAttribute("width",width);
        return(this);
    }
    /**
        Sets the HEIGHT="" attribute.

        @param  width sets the HEIGHT="" attribute.
    */
    public Table setHeight(String height)
    {
        addAttribute("height",height);
        return(this);
    }
    /**
        Sets the COLS="" attribute.

        @param  width sets the COLS="" attribute.
    */
    public Table setCols(int cols)
    {
        addAttribute("cols",Integer.toString(cols));
        return(this);
    }

    /**
        Sets the CELLPADING="" attribute.
        @param  cellpadding sets the CELLPADING="" attribute.
    */
    public Table setCellPadding(int cellpadding)
    {
        addAttribute("cellpadding",Integer.toString(cellpadding));
        return(this);
    }
    /**
        Sets the CELLSPACING="" attribute.
        @param  spacing sets the CELLSPACING="" attribute.
    */
    public Table setCellSpacing(int cellspacing)
    {
        addAttribute("cellspacing",Integer.toString(cellspacing));
        return(this);
    }
    /**
        Sets the BORDER="" attribute.
        @param  border sets the BORDER="" attribute.
    */
    public Table setBorder(int border)
    {
        addAttribute("border",Integer.toString(border));
        return(this);
    }
    /**
        Sets the FRAME="" attribute.
        @param  frame sets the FRAME="" attribute.
    */
    public Table setFrame(String frame)
    {
        addAttribute("frame",frame);
        return(this);
    }
    /**
        Sets the RULES="" attribute.
        @param  rules sets the RULES="" attribute.
    */
    public Table setRules(String rules)
    {
        addAttribute("rules",rules);
        return(this);
    }

    /**
        Sets the BGCOLOR="" attribute
        @param   color  the BGCOLOR="" attribute
    */
    public Table setBgColor(String color)
    {
        addAttribute("bgcolor",HtmlColor.convertColor(color));
        return this;
    }

    /**
        Adds an Element to the element.
        @param  hashcode name of element for hash table
        @param  element Adds an Element to the element.
     */
    public Table addElement(String hashcode,Element element)
    {
        addElementToRegistry(hashcode,element);
        return(this);
    }

    /**
        Adds an Element to the element.
        @param  hashcode name of element for hash table
        @param  element Adds an Element to the element.
     */
    public Table addElement(String hashcode,String element)
    {
        addElementToRegistry(hashcode,element);
        return(this);
    }

    /**
        Adds an Element to the element.
        @param  element Adds an Element to the element.
     */
    public Table addElement(Element element)
    {
        addElementToRegistry(element);
        return(this);
    }

    /**
        Adds an Element to the element.
        @param  element Adds an Element to the element.
     */
    public Table addElement(String element)
    {
        addElementToRegistry(element);
        return(this);
    }
    /**
        Removes an Element from the element.
        @param hashcode the name of the element to be removed.
    */
    public Table removeElement(String hashcode)
    {
        removeElementFromRegistry(hashcode);
        return(this);
    }
}